#!/bin/sh
# Sanity check
if [ "m`which lynx`" = "m" ]; then
	echo "Please, install lynx before executing this script\n"
	exit 3
fi
# Get optional parameters
progname=$0
build_args=
if [ "m$1" = "m-u" ]; then
	build_args=$1
	shift
fi
# Check parameters
if [ "m$1" = "m" ]; then
	echo "Syntax: $progname [-u] filename"
	echo "Use -u to only uncompress and patch (no build & install)"
	echo "Example: $progname XmAll.h"
	echo "Example: $progname -u bin/less"
	exit 0
fi
rm -f query.tmp.html packageinfo.tmp.html
# Get the name of the first package that contains that file
echo -n "Locating the package name... "
word="$1"
lynx -dump "http://packages.debian.org/cgi-bin/search_contents.pl?version=testing&arch=arm&case=insensitive&word=${word}&searchmode=searchword" > query.tmp.html
num=`cat query.tmp.html | grep "/${word} .*"  | grep '\[' | head -1 | sed "s/^.*\[\([0-9][0-9]*\)\].*\$/\1/g"`
url=`cat query.tmp.html | grep "^ *${num}. " | sed "s/^.*\(http:\)/\1/g"`
echo `echo $url | sed "s:^.*/\([^/]*/[^/]*\)\$:\1:g"`
if [ "m$url" = "m" ]; then
	echo "Problem locating the package, exiting..."
	exit 1
fi
# Get the URL of the orig.tar.gz and diff.gz of that package
echo ""
echo -n "Sources file... "
lynx -dump "$url" > packageinfo.tmp.html
sourcesurl=` cat packageinfo.tmp.html  | grep "\.orig\.tar\.gz\$" | sed "s/^.*\(http:\)/\1/g"`
echo "$sourcesurl"
echo -n "Patch file... "
patchurl=` cat packageinfo.tmp.html  | grep "\.diff\.gz\$" | sed "s/^.*\(http:\)/\1/g"`
echo "$patchurl"
if [ "m$sourcesurl" = "m" ] || [ "m$patchurl" = "m" ]; then
	echo "Problem getting the URLs, exiting..."
	exit 1
fi
echo ""
echo "Press ENTER if the selected package seems reasonable (ctrl-c if not)"
read dummy
# Download files
echo "Downloading files..."
for i in $sourcesurl $patchurl ; do
	filename=`echo $i | sed "s:^.*/\([^/]*\)\$:\1:g"`
	if [ ! -e $filename ]; then
		wget $i
	fi
done
# Get the name of the orig.tar.gz
echo -n "Getting the name of the sources file... "
sourcesname=`echo $sourcesurl | sed "s:^.*/\([^/]*\)\$:\1:g"`
echo "$sourcesname"
# Compile and install...
echo "Compiling and installing..."
if [ ! -e $sourcesname ]; then
	echo "ERROR: I cannot find $sourcesname in local filesystem"
	exit 2
fi
`echo $progname |sed "s:[^/]*\$::g"`unpack-n-patch-n-build-install.sh $build_args $sourcesname
# End
echo "All done."
