#!/bin/sh
dontbuild=0
progname=$0
if [ "m$1" = "m-u" ]; then
	dontbuild=1
	shift
fi
if [ ! -e "$1" ]; then
	echo "Syntax: $progname [-u] package_ver.orig.tar.gz"
	exit 1
fi
base=`echo $1 | cut -d "_" -f 1`
diffname=`ls $base*diff.gz | head -1 `
	echo "diff $diffname for $base "
if [ ! -e $diffname ]; then
	echo "Error: diff $diffname for $base not found"
	exit 2
fi
rm -f $1.tmp.list
tar -tzf $1 > $1.tmp.list
dir=`head -1 $1.tmp.list | cut -d "/" -f 1`
rm -f $1.tmp.list
if [ "m`echo $dir | sed 's:\.\./::g;s:\./::g' | tr -d '/' | tr -d ' '`" = "m" ]; then
	echo "ERROR: problem analyzing contents of tarball, exiting."
	exit 2
fi
rm -rf $dir
tar -xvzf $1
if [ ! -d $dir ]; then
	echo "Error: directory $dir not found"
	exit 2
fi
cd $dir
zcat ../$diffname | patch -p1
if [ -d upstream ]; then
	name=`cd upstream/tarballs ; ls -1 | head -1`
	echo "upstream tarball: $name"
	namebz2=`echo $name | sed "s/gz\$/bz2/g"`
	namebase=`echo $name | cut -d "-" -f 1`
	echo "new bz2: $namebz2"
	echo "new base: $namebase"
	zcat upstream/tarballs/$name | bzip2 > $namebz2
	mv debian/patches debian/patches-$namebase
fi
if [ "m`ls -1 debian | grep patches- | head -1`" != "m" ]; then
	echo "I'll have to reunpack this, it contains several archives:"
	ls -1 debian | grep patches-  | sed "s/^patches-/        /g"
	name=""
	echo ""
	while [ ! -e debian/patches-$name ]; do
		echo -n "Enter archive to reunpack: "
		read name
	done
	echo "repacking..."
	tarbz2=`ls $name*.tar.bz2 | head -1`
	echo "Original sources... $tarbz2"
	patchesdir="debian/patches-$name"
	echo "Patches dir... $patchesdir"
	if [ ! -e "$tarbz2" ] || [ ! -d "$patchesdir" ]; then
		echo "ERROR with archive $tarbz2 or with patches dir $patchesdir"
		exit 1
	fi
	mkdir orig
	mv * orig
	mkdir debian
	mv orig/debian/patches-$name debian/patches
	mv orig/$tarbz2 .
	rm -f filelist.tmp.list
	tar -tjf $tarbz2 > filelist.tmp.list
	dir=`head -1 filelist.tmp.list | cut -d "/" -f 1`
	rm -f filelist.tmp.list
	echo "dir... $dir"
	if [ "m`echo $dir | sed 's:\.\./::g;s:\./::g' | tr -d '/' | tr -d ' '`" = "m" ]; then
		echo "ERROR: problem analyzing contents of tarball, exiting."
		exit 2
	fi
	rm -rf $dir
	tar -xvjf $tarbz2
	mv ./$dir/* .
	rmdir $dir
fi
if [ ! -f debian/patches/series ]; then
	( cd debian/patches && ls -1 | grep "^[0-9]" | sort > series )
fi
if [ -f debian/patches/series ]; then
	echo "Aplying aditional patches"
	for i in `cat debian/patches/series | tr " " "#" | sed "s/\$/#/g"` ; do
		patchname=`echo $i | cut -d "#" -f1`
		patchlevel=`echo $i | cut -d "#" -f2`
		if [ "m$patchlevel" = "m" ]; then
			patchlevel="-p1"
		fi
		echo "patch $patchlevel < debian/patches/$patchname"
		patch $patchlevel < debian/patches/$patchname
	done
fi
if [ "m$dontbuild" = "m0" ]; then
	echo "./configure && make && make install"
	./configure && make && make install
else
	echo "To compile autotools-based programs:"
	echo "./configure && make && make install"
fi
echo "All done for $dir"
